# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from ..core.serialization import FieldMetadata
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class IntervalMonitorConfig(UniversalBaseModel):
    interval_seconds: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="intervalSeconds")] = (
        pydantic.Field(default=None)
    )
    """
    The interval in seconds between condition checks. Only used when monitorType is 'interval'.
    """

    timeout_seconds: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="timeoutSeconds")] = (
        pydantic.Field(default=None)
    )
    """
    The timeout in seconds after which the monitor will stop checking the condition.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.client_wrapper import SyncClientWrapper
import typing
from ..core.request_options import RequestOptions
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..types.extension_configuration_output import ExtensionConfigurationOutput
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..errors.not_found_error import NotFoundError
from ..types.error_model import ErrorModel
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..errors.internal_server_error import InternalServerError
from ..core.client_wrapper import AsyncClientWrapper


class ExtensionConfigurationsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def extension_configuration_delete(
        self,
        *,
        extension_configuration_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Delete extension configurations matching by name

        Parameters
        ----------
        extension_configuration_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A comma-separated list of extension configuration names.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.extension_configurations.extension_configuration_delete()
        """
        _response = self._client_wrapper.httpx_client.request(
            "extension-configuration",
            method="DELETE",
            params={
                "extensionConfigurationNames": extension_configuration_names,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def extension_configuration_get_info(
        self, name: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ExtensionConfigurationOutput:
        """
        Get an extension configuration by name

        Parameters
        ----------
        name : str
            Name of the extension configuration to get

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtensionConfigurationOutput
            OK

        Examples
        --------
        from airtop import Airtop

        client = Airtop(
            api_key="YOUR_API_KEY",
        )
        client.extension_configurations.extension_configuration_get_info(
            name="my-configuration",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"extension-configuration/{jsonable_encoder(name)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ExtensionConfigurationOutput,
                    parse_obj_as(
                        type_=ExtensionConfigurationOutput,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    typing.cast(
                        ErrorModel,
                        parse_obj_as(
                            type_=ErrorModel,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        ErrorModel,
                        parse_obj_as(
                            type_=ErrorModel,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        ErrorModel,
                        parse_obj_as(
                            type_=ErrorModel,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncExtensionConfigurationsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def extension_configuration_delete(
        self,
        *,
        extension_configuration_names: typing.Optional[typing.Union[str, typing.Sequence[str]]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Delete extension configurations matching by name

        Parameters
        ----------
        extension_configuration_names : typing.Optional[typing.Union[str, typing.Sequence[str]]]
            A comma-separated list of extension configuration names.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.extension_configurations.extension_configuration_delete()


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "extension-configuration",
            method="DELETE",
            params={
                "extensionConfigurationNames": extension_configuration_names,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def extension_configuration_get_info(
        self, name: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ExtensionConfigurationOutput:
        """
        Get an extension configuration by name

        Parameters
        ----------
        name : str
            Name of the extension configuration to get

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtensionConfigurationOutput
            OK

        Examples
        --------
        import asyncio

        from airtop import AsyncAirtop

        client = AsyncAirtop(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.extension_configurations.extension_configuration_get_info(
                name="my-configuration",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"extension-configuration/{jsonable_encoder(name)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ExtensionConfigurationOutput,
                    parse_obj_as(
                        type_=ExtensionConfigurationOutput,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    typing.cast(
                        ErrorModel,
                        parse_obj_as(
                            type_=ErrorModel,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        ErrorModel,
                        parse_obj_as(
                            type_=ErrorModel,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        ErrorModel,
                        parse_obj_as(
                            type_=ErrorModel,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
from .monitor_config_include_visual_analysis import MonitorConfigIncludeVisualAnalysis
from ..core.serialization import FieldMetadata
import pydantic
from .interval_monitor_config import IntervalMonitorConfig
from .browser_wait_selector_config import BrowserWaitSelectorConfig
from .monitor_config_monitor_type import MonitorConfigMonitorType
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class MonitorConfig(UniversalBaseModel):
    include_visual_analysis: typing_extensions.Annotated[
        typing.Optional[MonitorConfigIncludeVisualAnalysis], FieldMetadata(alias="includeVisualAnalysis")
    ] = pydantic.Field(default=None)
    """
    If set to 'enabled', Airtop AI will also analyze the web page visually when executing the condition check. If set to 'disabled', no visual analysis will be conducted.
    """

    interval: typing.Optional[IntervalMonitorConfig] = pydantic.Field(default=None)
    """
    Configuration for the interval monitor. Only used when monitorType is 'interval'.
    """

    monitor_selector_options: typing_extensions.Annotated[
        typing.Optional[BrowserWaitSelectorConfig], FieldMetadata(alias="monitorSelectorOptions")
    ] = pydantic.Field(default=None)
    """
    Configuration for the browser wait selector.
    """

    monitor_type: typing_extensions.Annotated[MonitorConfigMonitorType, FieldMetadata(alias="monitorType")] = (
        pydantic.Field()
    )
    """
    The type of monitoring to perform. Interval executes the condition check at a regular, specified interval. Selector waits for a selector to be present before completing.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
import typing
import datetime as dt
from ..core.serialization import FieldMetadata
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ExtensionConfigurationOutput(UniversalBaseModel):
    created_at: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="createdAt")] = (
        pydantic.Field(default=None)
    )
    """
    The date and time the configuration was created. Might be null for old configurations
    """

    extension_ids: typing_extensions.Annotated[
        typing.Optional[typing.List[str]], FieldMetadata(alias="extensionIds")
    ] = pydantic.Field(default=None)
    """
    The ids of the extensions in configuration.
    """

    name: str = pydantic.Field()
    """
    Name of the extension configuration.
    """

    updated_at: typing_extensions.Annotated[typing.Optional[dt.datetime], FieldMetadata(alias="updatedAt")] = (
        pydantic.Field(default=None)
    )
    """
    The date and time the configuration was last updated. Might be null for configurations not updated recently
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
import typing_extensions
from ..core.serialization import FieldMetadata
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class BrowserWaitSelectorConfig(UniversalBaseModel):
    hidden: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, Airtop AI will wait for the element to not be in the DOM or to be hidden.
    """

    timeout_seconds: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="timeoutSeconds")] = (
        pydantic.Field(default=None)
    )
    """
    The maximum time to wait for the selector to be present, in seconds. Defaults to 30 (30 seconds).
    """

    visible: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, Airtop AI will wait for the element to be visible and present in the DOM.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
